Invoice INV-2025-0010

# Acme Services Ltd

123 Business Way, New York, NY 10001
Tax ID: NY-123456789

## INVOICE

#INV-2025-0010
Date: 2025-12-31
Due: 2026-01-14

Bill To:
Tech Solutions Inc.
456 Innovation Drive, Suite 100, San Francisco, CA
Tax ID: US-987654321

Description | Quantity | Unit Price | Total
--- | --- | --- | ---
Cloud Infrastructure Setup | 1 | $2500.00 | $2500.00
Software Development (Frontend) | 40 | $120.00 | $4800.00
Backend Integration Services | 20 | $150.00 | $3000.00

Subtotal: $10300.00
Total Amount: $10300.00